from Rafflesia.Audio import busy
from Rafflesia.Audio  import load
from Rafflesia.Audio  import play
from Rafflesia.Audio  import pos
from Rafflesia.Audio  import rewind
from Rafflesia.Audio  import stop
from Rafflesia.Audio  import pause
from Rafflesia.Audio  import unpause
from Rafflesia.Audio  import volume
import pygame

pygame.mixer.set_num_channels(2048)


class AudioManager:
    def __init__(self, dev=False):
        self.channelidlist = []
        self.dev = dev
        super(AudioManager, self).__init__()

    def shortplay(self, filepath, channelname):
        play.shortplay(filepath)

    def long_load(self, filepath):
        load.long_load(filepath, self.dev)

    def long_play(self, loops=0, start=0.0, infinityloop=False):
        play.long_play(loops, start, infinityloop, self.dev)

    def long_rewind(self):
        rewind.long_rewind(self.dev)

    def long_stop(self):
        stop.long_stop(self.dev)

    def long_pause(self):
        pause.long_pause(self.dev)

    def long_unpause(self):
        unpause.long_unpause(self.dev)

    def long_get_busy(self):
        return busy.long_get_busy(self.dev)

    def long_get_volume(self):
        return volume.long_get_volume(self.dev)

    def long_set_volume(self, value):
        volume.long_set_volume(value, self.dev)

    def long_get_pos(self):
        return pos.long_get_pos(self.dev)

    def long_set_pos(self, value):
        pos.long_set_pos(value, self.dev)





import pygame


def long_rewind(dev):
    try:
        pygame.mixer.music.rewind()
        if dev:
            print("Rafflesia Audio / longrewind: long 다시 재생")
    except Exception as e:
        print(e)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="Rafflesia",  ## 소문자 영단어
    version="0.0.6",  ##
    author="QU4R7Z",  ## ex) Sunkyeong Lee
    author_email="shio7113@gmail.com",  ##
    description="Rafflesia Framework",  ##
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/QU4R7Z/Rafflesia",  ##
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)



import pygame


def shortplay(filepath):
    channelname = pygame.mixer.Channel()
    print(filepath)


def long_play(loops, start, infinityloop, dev):
    try:
        if infinityloop:
            pygame.mixer.music.play(-1)
            if dev:
                print(f"Rafflesia Audio / longplay: long 무한 반복재생")
        else:
            pygame.mixer.music.play(loops, start)
            if dev:
                print(f"Rafflesia Audio / longplay: {loops} 번 반복, {start}부터 시작")
    except Exception as e:
        print(e)
